#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <limits.h>
#include "combinat.h"
#include "oms_error.h"


static void usage(char **argv){
  printf("usage: %s [-e] [-o outfile ] -d dim  -n elements\n",argv[0]);
  exit(1);
}


int main(int argc, char** argv){
  int n=4,d=3,f=-1,reps=1;
  long seed1=55555;
  long seed2=99999;
  int i;
  int c;
  int delta;
  char filename[PATH_MAX];
  char *nextarg;
  natural_t *pi;
  int iteration;


  filename[0]=0;

  while((c=getopt(argc,argv,"o:n:d:s:f:r:"))!=-1){
    switch(c){
    case 'o':
      strncpy(filename,optarg,PATH_MAX);
      break;
    case 'd':
      d=atoi(optarg);
      break;
    case 'n':
      n=atoi(optarg);
      break;
    case 'f':
      f=atoi(optarg);
      break;
    case 's':
      seed1=strtol(optarg,&nextarg,10);
      seed2=strtol(nextarg+1,NULL,10);
      break;
    case 'r':
      reps=atoi(optarg);
      break;
    default:
      usage(argv);
      exit(1);

    }
  }

  set_seed(seed1,seed2);

  delta=binomial(n,d);

  if (f==-1)
    f=Gamma(n,d);

  if (f>Gamma(n,d))
    fprintf(stderr,"Warning: f > Gamma(n,d)=%d\n",Gamma(n,d));
    
  pi=calloc(delta,sizeof(natural_t));

  for (iteration=0; iteration<reps; iteration++){
    if (strlen(filename)>0){
      char buffer[PATH_MAX];
      if (reps>1){
	snprintf(buffer,PATH_MAX,filename,iteration);
	freopen(buffer,"w",stdout);
      } else {
	freopen(filename,"w",stdout);
      }

      oms_assert(stdout);

    }
    random_permutation(delta,pi);

    printf("#start seed %ld:%ld\n",seed1,seed2);

    printf("rank=%d\n",d+1);
    printf("elements=%d\n",n);
    printf("chirotope={1}\n");
    printf("boundary={\n");
    for (i=0; i<f; i++){
      printf("%d\n",pi[i]);
    }
    printf("}\n");
  
    get_seed(&seed1,&seed2);
    
    printf("#end seed %ld:%ld\n",seed1,seed2);
  }
}
