/* z_ps2d.h

   ZRAM: 2-dimensional point set

   Ambros Marzetta

   95-07-15
 * $Source$
 * $Revision$
 * $Date$
 * $Log$
 * Revision 1.2  2000/11/15 16:14:52  bremner
 * committing patched version of zram source
 *
 * Revision 1.1  1996/06/03  19:02:29  marzetta
 * Initial revision
 *
 */

#ifndef _Z_PS2D_H_
#define _Z_PS2D_H_
#include "z_base.h"
#include <stdio.h>

typedef float ps2d_coordT;	/* coordinate in Euclidean space */
				/* must be compatible to scanf format */

extern int z_ps2dTag;

typedef struct z_ps2d {
  Z_NODE_HEADER;		/* len; tag = z_ps2dTag; children = 0 */
  int numPt;			/* number of points */
  ps2d_coordT ps2d_data[1];	/* variable size */
				/* ps2d_coord_x[]: x coordinate */
				/* ps2d_coord_y[]: y coordinate */
} z_ps2dT, *z_ps2dP;

#define ps2d_coord_x(gp, i)	(gp->ps2d_data[2*(i)])
#define ps2d_coord_y(gp, i)	(gp->ps2d_data[2*(i)+1])
				/* must be adjacent in memory for qsort() */
				/* in est application */

z_ps2dP z_ps2d_New(int numPt);
/* Allocate a 2-dimensional point set with numPt points */

void z_ps2d_Free(z_ps2dP node);
/* Deallocate a 2-dimensional point set */

void z_ps2d_ReadStart(z_ps2dP ps2d);
/* Initialize the point set with random coordinates in 0..999 */

void z_ps2d_Read(FILE *infile, z_ps2dP ps2d);
/* Read one line from the input file (format: %d:%f%f) */

void z_ps2d_Init(void);
/* Initialize this module */

#endif /* _Z_PS2D_H_ */
